<?php

namespace Drupal\google_analytics_events;

class Event {

  private $id;

  protected $hit_type;

  protected $event_category;

  protected $event_action;

  protected $event_label;

  protected $event_value;

  public function __construct() {
    $this->id = uniqid(microtime(TRUE), TRUE);
  }

  /**
   * Validate the length of a string in bytes.
   * 
   * @param string $data 
   *   Data to verify.
   * @param int $length 
   *   Maximum length in bytes.
   * @throws \Exception 
   */
  protected function validateLength($data, $length) {
    if (mb_strlen($data, '8bit') > $length) {
      throw new \Exception("Invalide parameter length.");
    }
  }

  /**
   * Summary of setHitType
   *
   * @param string $type
   */
  public function setHitType($type) {
    if (!in_array($type, ['pageview', 'screenview', 'event', 'transaction', 'item', 'social', 'exception', 'timing'])) {
      throw new \InvalidArgumentException('Hit type not valid.');
    }
    $this->hit_type = $type;
    return $this;
  }

  /**
   * Category for the event
   *
   * @param string $category
   *
   * @return Event
   */
  public function setEventCategory($category) {
    $this->validateLength($category, 150);
    $this->event_category = $category;
    return $this;
  }

  /**
   * Action for the event
   *
   * @param string $action
   * @return Event
   */
  public function setEventAction($action) {
    $this->validateLength($action, 500);
    $this->event_action = $action;
    return $this;
  }

  /**
   * Label for the event
   *
   * @param string $label
   * @return Event
   */
  public function setEventLabel($label) {
    $this->validateLength($label, 500);
    $this->event_label = $label;
    return $this;
  }

  /**
   * Value of the event
   *
   * @param int $value
   * @return Event
   */
  public function setEventValue($value) {
    if (!is_int($value)) {
      throw new \InvalidArgumentException("Event value must be an integer.");
    }
    $this->event_value = $value;
    return $this;
  }

  /**
   * Return an array of data ready
   * to send to the client script.
   * 
   * @return array
   */
  public function toArray() {
    return [
      'hit_type' => $this->hit_type,
      'event_category' => $this->event_category,
      'event_action' => $this->event_action,
      'event_label' => $this->event_label,
      'event_value' => $this->event_value,
      'id' => $this->id,
    ];
  }
}
